"""my own config parser, perhaps use another one sometime

Just initialize it with Config.Config(configfile)
While the configfile is optional"""

import os, sys, shutil

DEBUG = False

class Config:
	"""Pass this object to all modules! This is the config"""
	def __init__(self, file=False):
		self.entries = {}
		if not file:
			self.file = self.get_filename()
			if DEBUG:
				print self.file, "found as config file"
		else:
			self.file = file
		self.load_file(self.file)
		if DEBUG:
			print self
	def __getattr__(self, name):
		"""a self.name call if not already found"""
		# is this safe? can functions still be called?
		if self.entries.has_key(name):
			return self.entries[name]
		else:
			# perhaps we should raise an error?
			return False
	def __str__(self):
		"""called if you print the object"""
		if DEBUG:
			print self.entries
		text = ""
		for key, value in self.entries.items():
			text += '%s: %s\n' % (key, value)
		return text
	def load_file(self, file):
		"""load the configuration from the given file"""
		for line in open(file):
			line = line.strip()
			if DEBUG:
				print "parsing:", line
			if len(line) == 0 or line[0] == '#':
				# it is a comment
				continue
			else:
				self.parse_config(line)
	def parse_config(self, line):
		"""parses the given line of the configuration file"""
		var, value = line.split("=")
		var = var.strip()
		value = value.strip()
		if value.find(',') != -1:
			# multiple values, make it a list
			value = value.split(',')
			value = map(self.parse_value, value)
			self.entries[var] = value
		else:
			self.entries[var] = self.parse_value(value)
	def parse_value(self, value):
		"""parse a value
		i.e. "yes" -> True"""
		value = value.strip()
		boolean_true = ["yes", "1", "true"]
		boolean_false = ["no", "0", "false"]
		if value.strip() in boolean_true:
			return True
		elif value.strip() in boolean_false:
			return False
		else:
			# could be an integer
			try:
				number = int(value).__str__()
				if number == value:
					return int(value)
			except:
				pass
		return value
	def get_filename(self):
		"""look for a config file
		Looking (in this order)
		1. args
		2. home dir
		3. /etc"""
		my_dir = os.path.expanduser("~/.feedisto")
		if not os.path.exists(my_dir):
			os.mkdir(my_dir)
		self.my_dir = my_dir
		configfile = my_dir + "/config"
		if not os.path.exists(configfile):
			config_default_file = sys.prefix + "share/feedisto/config_default"
			shutil.copyfile(config_default_file, configfile)
		# 1. args
		# 2. home dir
		# 3. /etc

		# if can't find anything use some defaults!
		return configfile

if __name__ == "__main__":
	test = Config()
	print dir(test)
	print test.title
