"""all news items must be packed into this class"""

import sys, re

DEBUG = False

class NewsItem:
	def __init__(self, title, url):
		# these are the necessary properties of a news item
		url = url.replace("&", "&amp;")
		self.title = title
		self.url = url # url of the feed
		self.link = "" # url of the article
		self.expose = ""
		self.text = ""
		self.image = ""
		self.date = ""
		self.hashint = False
		self.relevance = 0.0
		self.encoding = "UTF-8"
		self.tags = re.compile("<.*>")
	def __str__(self):
		"""by print just the title and the link"""
		return '%s (%s)' % (self.title, self.link)
	def __cmp__(self, other):
		"""standard compare, compares by relevance"""
		# the - because we want highest value first
		return - cmp(self.relevance, other.relevance)
	def set_date(self, date):
		try:
			self.date = date.encode("ISO-latin-1")
		except LookupError:
			if DEBUG:
				print "date.encode failed, returning raw date:", date
			self.date = date
	def set_link(self, url):
		self.link = url.replace("&", "&amp;")
	def set_text(self, text):
		self.text += "\n" + text
	def set_expose(self, text):
		self.expose = text
	def set_image(self, imgobj):
		"""the given image must be an object, like feedparser returns"""
		self.image = imgobj
	def set_encoding(self, enc):
		self.encoding = enc
	def html(self):
		html_template = """
		<div class=\"item\">
			<h1 class="item"><a href=\"%s\">%s</a></h1>
			<p class="data">%s</p>
			<p class="summary">%s</p>
			<p class="content">%s</p>
		</div><!-- ############################# -->"""
		data  = "newsurl: %s<br />\ndate: %s<br />\nhash: %s<br />\nrelevance: %.3f<br />\n" % (self.url, self.date, self.hash(), self.relevance)
		html = html_template % (self.link, self.title, data, self.expose, self.text)
		return html
	def raw_text(self):
		raw = "%s ( %s )\n%s\n%s\n%s" % (self.title, self.link, self.url, self.strip_tags(self.expose), self.strip_tags(self.text))
		raw = raw.encode("latin-1", 'ignore')
		return raw
	def hash(self):
		if not self.hashint:
			text = "%s-%s" % (self.title, self.url)
			self.hashint = hash( text.encode('iso-8859-1', 'ignore') )
		return int(self.hashint)
	def strip_tags(self, html):
		text = self.tags.sub("", html, 100)
		return text.strip()
	
