import sys, os

import Feedisto
import Config
import Modules

DEBUG = False

class WorkFlow:
	def __init__(self, configfile=False):
		self.inputs = []
		self.parser = []
		self.outputs = []
		self.config = Config.Config(configfile)
		modulepath = self.config.modulepath
		if modulepath:
			modulepath = os.path.expanduser(modulepath)
		self.load_plugins(self.config.modules, modulepath)
	def add_input(self, input):
		self.inputs.append(self, input)
	def add_output(self, output):
		self.outputs.append(self, output)
	def add_parser(self, parser):
		self.parser.append(self, parser)
	def run(self):
		"""here is the whole action, getting the news, parsing them and spit it our again"""
		bunch = []
		if DEBUG:
			print "there are %i input plugins" % len(self.inputs)
		for input in self.inputs:
			stuff = input.get()
			for thingy in stuff:
				bunch.append(thingy)
		if DEBUG:
			print "got %i news items" % len(bunch)
			print "now there are %i parser plugins" % len(self.parser)
		for parser in self.parser:
			bunch = parser.parse(bunch)
		bunch.sort()
		if DEBUG:
			print "after parsing them, there are %i items" % len(bunch)
			print "now there are %i output plugins" % len(self.outputs)
		for output in self.outputs:
			output.put(bunch)
		return len(bunch)
	def load_plugins(self, pluginlist, path="./plugins/"):
		# collect paths
		paths = [path]
		try:
			paths.append( Modules.__path__[0])
			paths.append( Feedisto.__path__[0])
		except:
			if DEBUG:
				print "Feedisto module has no __path__"
		if DEBUG:
			print "paths to look for modules:", paths
		for plugin in pluginlist:
			if DEBUG:
				print "loading module:", plugin
			self.load_plugin(plugin, paths)
	def load_plugin(self, plugin, paths):
		import imp
		# check if we haven't loaded it already
		try:
			return sys.modules[plugin]
		except KeyError:
			pass
		# ok, the load it
		fp, filename, desc = imp.find_module(plugin, paths)
		try:
			mod = imp.load_module(plugin, fp, filename, desc)
		finally:
			if fp:
				fp.close()
		# instantiate and put into basket
		clazz = mod.main(self.config)
		if "input" in clazz.types:
			self.inputs.append(clazz)
		if "parser" in clazz.types:
			self.parser.append(clazz)
		if "output" in clazz.types:
			self.outputs.append(clazz)


if __name__ == "__main__":
	bobby = WorkFlow()
	bobby.run()
